==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/FixedWidthNumberDecorator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_FIXED_WIDTH_NUMBER_DECORATOR_H_
#define _D_FIXED_WIDTH_NUMBER_DECORATOR_H_

#include "NumberDecorator.h"
#include "Util.h"

class FixedWidthNumberDecorator : public NumberDecorator
{
private:
  int32_t _width;
public:
  FixedWidthNumberDecorator(int32_t width):_width(width) {}

  virtual ~FixedWidthNumberDecorator() {}

  virtual string decorate(int32_t number)
  {
    string s = Util::itos(number);
    while(s.size() < (size_t)_width) {
      s.insert(0, "0");
    }
    return s;
  }
};

#endif // _D_FIXED_WIDTH_NUMBER_DECORATOR_H_

==> aria2_1.4.1.orig.tar.gz: aria2-1.4.1/src/FixedWidthNumberDecorator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_FIXED_WIDTH_NUMBER_DECORATOR_H_
#define _D_FIXED_WIDTH_NUMBER_DECORATOR_H_

#include "NumberDecorator.h"
#include "Util.h"

namespace aria2 {

class FixedWidthNumberDecorator : public NumberDecorator
{
private:
  size_t _width;
public:
  FixedWidthNumberDecorator(size_t width):_width(width) {}

  virtual ~FixedWidthNumberDecorator() {}

  virtual std::string decorate(unsigned int number)
  {
    std::string s = Util::uitos(number);
    while(s.size() < _width) {
      s.insert(0, "0");
    }
    return s;
  }
};

} // namespace aria2

#endif // _D_FIXED_WIDTH_NUMBER_DECORATOR_H_
